@@ -20,7 +20,7 @@ COORDINATE_FORMAT: Final[str] = '({:.2f}, {:.2f}, {:.2f})'
 
 
 class DrawableSkeleton(Group):
-    def __init__(self, joint_points: List[Points], joint_lines: List[Line],
+    def __init__(self, joint_set: JointSet, joint_points: List[Points], joint_lines: List[Line],
                  joint_names: List[Text] = None, joint_coordinates: List[Text] = None):
         drawable_objects: List[Drawable] = joint_points + joint_lines
         if joint_names is not None:
@@ -28,11 +28,30 @@ class DrawableSkeleton(Group):
         if joint_coordinates is not None:
             drawable_objects += joint_coordinates
         super().__init__(drawable_objects)
+        self.joint_set: JointSet = joint_set
         self.joint_points: List[Points] = joint_points
         self.joint_lines: List[Line] = joint_lines
         self.joint_names: List[Text] = joint_names
         self.joint_coordinates: List[Text] = joint_coordinates
 
+    def get_left_objects(self) -> List[Drawable]:
+        return [self.joint_points[left_point_index]
+                for left_point_index in self.joint_set.left_joint_indices] + \
+               [self.joint_lines[left_line_index]
+                for left_line_index in self.joint_set.left_line_indices]
+
+    def get_right_objects(self) -> List[Drawable]:
+        return [self.joint_points[right_point_index]
+                for right_point_index in self.joint_set.right_joint_indices] + \
+               [self.joint_lines[right_line_index]
+                for right_line_index in self.joint_set.right_line_indices]
+
+    def get_center_objects(self) -> List[Drawable]:
+        return [self.joint_points[center_point_index]
+                for center_point_index in self.joint_set.center_joint_indices] + \
+               [self.joint_lines[center_line_index]
+                for center_line_index in self.joint_set.center_line_indices]
+
 
 class Skeleton:
     def __init__(self, joint_positions: Positions,
@@ -45,36 +64,36 @@ class Skeleton:
     def to_drawable_skeleton(self) -> DrawableSkeleton:
         joint_points: List[Points] = self.__get_joint_points()
         joint_lines: List[Line] = self.__get_joint_lines()
-        return DrawableSkeleton(joint_points, joint_lines)
+        return DrawableSkeleton(self.joint_set, joint_points, joint_lines)
 
     def to_drawable_skeleton_with_names(self) -> DrawableSkeleton:
         joint_points: List[Points] = self.__get_joint_points()
         joint_lines: List[Line] = self.__get_joint_lines()
         joint_names: List[Text] = self.__get_joint_names()
-        return DrawableSkeleton(joint_points, joint_lines, joint_names=joint_names)
+        return DrawableSkeleton(self.joint_set, joint_points, joint_lines, joint_names=joint_names)
 
     def to_drawable_skeleton_with_coordinates(self) -> DrawableSkeleton:
         joint_points: List[Points] = self.__get_joint_points()
         joint_lines: List[Line] = self.__get_joint_lines()
         joint_coordinates: List[Text] = self.__get_joint_coordinates()
-        return DrawableSkeleton(joint_points, joint_lines, joint_coordinates=joint_coordinates)
+        return DrawableSkeleton(self.joint_set, joint_points, joint_lines, joint_coordinates=joint_coordinates)
 
     def to_drawable_skeleton_for_video(self) -> DrawableSkeleton:
         joint_points: List[Points] = self.__get_joint_points_for_video()
         joint_lines: List[Line] = self.__get_joint_lines_for_video()
-        return DrawableSkeleton(joint_points, joint_lines)
+        return DrawableSkeleton(self.joint_set, joint_points, joint_lines)
 
     def to_drawable_skeleton_for_video_with_names(self) -> DrawableSkeleton:
         joint_points: List[Points] = self.__get_joint_points_for_video()
         joint_lines: List[Line] = self.__get_joint_lines_for_video()
         joint_names: List[Text] = self.__get_joint_names_for_video()
-        return DrawableSkeleton(joint_points, joint_lines, joint_names=joint_names)
+        return DrawableSkeleton(self.joint_set, joint_points, joint_lines, joint_names=joint_names)
 
     def to_drawable_skeleton_for_video_with_coordinates(self) -> DrawableSkeleton:
         joint_points: List[Points] = self.__get_joint_points_for_video()
         joint_lines: List[Line] = self.__get_joint_lines_for_video()
         joint_coordinates: List[Text] = self.__get_joint_coordinates_for_video()
-        return DrawableSkeleton(joint_points, joint_lines, joint_coordinates=joint_coordinates)
+        return DrawableSkeleton(self.joint_set, joint_points, joint_lines, joint_coordinates=joint_coordinates)
 
     def __get_joint_points(self) -> List[Points]:
         skeleton_joint_colors: np.ndarray = self.__get_joint_colors()
@@ -148,8 +167,8 @@ class Skeleton:
             text={
                 current_timestamp[0]: COORDINATE_FORMAT.format(
                     current_timestamp[1][joint_index][0],
-                    current_timestamp[1][joint_index][0],
-                    current_timestamp[1][joint_index][0])
+                    current_timestamp[1][joint_index][1],
+                    current_timestamp[1][joint_index][2])
                 for current_timestamp in self.joint_positions.items()
             }, position={
                 current_timestamp[0]: current_timestamp[1][joint_index]
